==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/WindowsBase/System.Windows.Threading/DispatcherSynchronizationContext.cs <==
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (c) 2007 Novell, Inc. (http://www.novell.com)
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//

using System;
using System.Security;
using System.Threading;

namespace System.Windows.Threading {

	public class DispatcherSynchronizationContext : SynchronizationContext
	{
		public DispatcherSynchronizationContext ()
		{
			throw new NotImplementedException ();
		}

		public DispatcherSynchronizationContext (Dispatcher dispatcher)
		{
			throw new NotImplementedException ();
		}

		public override SynchronizationContext CreateCopy ()
		{
			throw new NotImplementedException ();
		}

		public override void Post (SendOrPostCallback d, object state)
		{
			throw new NotImplementedException ();
		}

		public override void Send (SendOrPostCallback d, object state)
		{
			throw new NotImplementedException ();
		}

		[SecurityCritical]
		public override int Wait (IntPtr[] waitHandles, bool waitAll, int millisecondsTimeout)
		{
			throw new NotImplementedException ();
		}
	}

}

==> mono-4.4.2.11.tar.bz2: mono-4.4.2/mcs/class/WindowsBase/System.Windows.Threading/DispatcherSynchronizationContext.cs <==
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (c) 2007 Novell, Inc. (http://www.novell.com)
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//

using System;
using System.Security;
using System.Threading;

namespace System.Windows.Threading {

	public sealed class DispatcherSynchronizationContext : SynchronizationContext
	{
		public DispatcherSynchronizationContext ()
		{
			throw new NotImplementedException ();
		}

		public DispatcherSynchronizationContext (Dispatcher dispatcher)
		{
			throw new NotImplementedException ();
		}

		public override SynchronizationContext CreateCopy ()
		{
			throw new NotImplementedException ();
		}

		public override void Post (SendOrPostCallback d, object state)
		{
			throw new NotImplementedException ();
		}

		public override void Send (SendOrPostCallback d, object state)
		{
			throw new NotImplementedException ();
		}

		[SecurityCritical]
		public override int Wait (IntPtr[] waitHandles, bool waitAll, int millisecondsTimeout)
		{
			throw new NotImplementedException ();
		}
	}

}
